@@ -144,7 +144,9 @@ public:
             return QStringLiteral("1");
         }
 
-        return QLatin1String("agent = '") + (agent == QLatin1String(":current") ? QCoreApplication::instance()->applicationName() : agent) + QLatin1String("'");
+        return QLatin1String("agent = '")
+            + Common::escapeSqliteLikePattern(agent == QLatin1String(":current") ? QCoreApplication::instance()->applicationName() : agent)
+            + QLatin1String("'");
     }
 
     QString activityClause(const QString &activity) const
@@ -154,7 +156,8 @@ public:
         }
 
         return QLatin1String("activity = '") + //
-            (activity == QLatin1String(":current") ? ActivitiesSync::currentActivity(activities) : activity) + QLatin1String("'");
+            Common::escapeSqliteLikePattern(activity == QLatin1String(":current") ? ActivitiesSync::currentActivity(activities) : activity)
+            + QLatin1String("'");
     }
 
     inline QString starPattern(const QString &pattern) const
